import { initializeMenta } from ".";
import { EventBuilder, Show, ShowBuilder, TicketBuilder, TicketOption } from "./model/model";

const menta = initializeMenta('menta-public-key-000', 'local')

test("create event with builders", async () => {
    const event = new EventBuilder()
        .withEventId("lollapalooza-argentina-2023")
        .withTitle("Lollapalooza Argentina")
        .withLocation("Buenos Aires", "Buenos Aires", "Hipódromo de San Isidro", "Av. Marquez 1000, San Isidro, Buenos Aires", "Argentina")
        .withDescription("¡Bienvenidos al Lollapalooza Argentina! Este festival de música es uno de los eventos más esperados del año, donde podrás disfrutar de una experiencia única llena de música, arte y entretenimiento. Durante dos días, podrás bailar y cantar al ritmo de tus artistas favoritos, rodeado de una comunidad apasionada por la música y la cultura.  Este año, el Lollapalooza Argentina se llevará a cabo en el Hipódromo de San Isidro, uno de los lugares más emblemáticos de la ciudad de Buenos Aires. El festival contará con más de 100 artistas en vivo, incluyendo algunos de los más grandes nombres de la música nacional e internacional. Desde rock hasta pop, electrónica, hip-hop y mucho más, habrá algo para todos los gustos.  Además de la música, el Lollapalooza Argentina también contará con una gran variedad de actividades para que puedas disfrutar al máximo. Desde instalaciones de arte y experiencias interactivas hasta opciones de comida y bebida de alta calidad, todo está diseñado para ofrecerte una experiencia única e inolvidable.  El festival también tiene un compromiso con la sostenibilidad y el cuidado del medio ambiente. Por eso, se han implementado una serie de medidas para reducir el impacto ambiental del evento. Desde la utilización de energías renovables hasta la reducción de residuos y la promoción del transporte sustentable, el Lollapalooza Argentina está comprometido con un futuro más verde y sostenible.  No te pierdas la oportunidad de ser parte de esta gran fiesta. Compra tus entradas ahora y prepárate para vivir una experiencia inolvidable en el Lollapalooza Argentina. ¡Te esperamos!")
        .addShow(new ShowBuilder()
            .withTitle("Day 1 - Viernes")
            .withDateStart(new Date(Date.parse("2023-03-17T15:00:00.000Z")))
            .withShowId("lollaar-day1-2023")
            .addImage("https://storage.googleapis.com/default_mentatickets-core/63ff5001351e4be3a6d6429c_LOLLA_1920x720%20DF.png", "main")
            .addTicketOption({
                currency: "ARS",
                price: 15000,
                description: "General access",
                title: "General",
                ticketId: "01"
            } as TicketOption)
            .addTicketOption({
                currency: "ARS",
                price: 30000,
                description: "VIP access",
                title: "VIP",
                ticketId: "02"
            } as TicketOption)
            .build())
        .addShow(new ShowBuilder()
            .withTitle("Day 2 - Sábado")
            .withDateStart(new Date(Date.parse("2023-03-18T15:00:00.000Z")))
            .withShowId("lollaar-day2-2023")
            .addImage("https://storage.googleapis.com/default_mentatickets-core/63ff5001351e4be3a6d6429c_LOLLA_1920x720%20DF.png", "main")
            .addTicketOption({
                currency: "ARS",
                price: 15000,
                description: "General access",
                title: "General",
                ticketId: "01"
            } as TicketOption)
            .addTicketOption({
                currency: "ARS",
                price: 30000,
                description: "VIP access",
                title: "VIP",
                ticketId: "02"
            } as TicketOption).build()
        ).build()
    const response = await menta.createEvent(event)

    console.info(response)
});

test("get resale entrypoint for eventId", async () => {
    const eventId = "4321412"
    const showId = "000000091-3"
    const url = await menta.generateResaleUrl(eventId, showId)
    console.info(url)
})

test("tokenize only one ticket with builder", async () => {
    const tickets = [
        new TicketBuilder()
            .withExternalReferenceEventId("lollapalooza-argentina-2023")
            .withShowId("lollaar-day1-2023")
            .withTicketId("00000000001")
            .withTicketOptionId("01")
            .withBuyer("buyer@mentatickets.com")
            .withTicketAccess("https://storage.googleapis.com/default_mentatickets-core/qr-test.png", "URL")
            .build()
    ]

    const token = await menta.createTickets(tickets)
    console.info(token)
})

test("tokenize multiple tickets with builder", async () => {
    const ticketsIds = ["100", "101", "102", "103"]

    const tokens = ticketsIds.map(ticketId => new TicketBuilder()
        .withExternalReferenceEventId("lollapalooza-argentina-2023")
        .withShowId("lollaar-day1-2023")
        .withTicketId(ticketId)
        .withTicketOptionId("01")
        .withBuyer("buyer@mentatickets.com")
        .withTicketAccess("https://storage.googleapis.com/default_mentatickets-core/qr-test.png", "URL")
        .build())

    const tokenization = await menta.createTickets(tokens)

    console.info(tokenization)
})