import axios, { AxiosInstance } from "axios";
import { Response } from "../model/model";

export class httpClient {
    private instance: AxiosInstance
    constructor(apiKey: string, baseUrl: string) {
        this.instance = axios.create({
            baseURL: baseUrl,
            headers: {
                "Content-Type": 'application/json',
                Authorization: apiKey
            }
        })
    }

    public async get(url: string): Promise<Response> {
        try {
            const call = await this.instance.get(url)
            return {
                status: call.status,
                data: call.data
            }
        } catch (error: any) {
            const err = {
                status: error.response.data.status,
                data: error.response.data.errors
            }
            console.error(err)
            return err
        }
    }

    public async post(url: string, data: any): Promise<Response> {
        try {
            const call = await this.instance.post(url, data)
            return {
                status: call.status,
                data: call.data
            }
        } catch (error: any) {
            const err = {
                status: error.response.data.status,
                data: error.response.data.errors
            }
            console.error(err)
            return err
        }
    }
}